@@ -1,6 +1,7 @@
 use std::io::Result;
 use std::future::Future;
 use std::marker::PhantomData;
+use std::fmt::{Display, Formatter};
 
 use super::{IOStream, AsyncAccept, AsyncConnect};
 
@@ -20,14 +21,20 @@ pub struct WsConf {
     pub path: String,
 }
 
+impl Display for WsConf {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(f, "host: {}, path: {}", self.host, self.path)
+    }
+}
+
 // =========== client ==========
-#[derive(Clone, Copy)]
+#[derive(Debug, Clone, Copy)]
 pub struct Simple {}
 
-#[derive(Clone, Copy)]
+#[derive(Debug, Clone, Copy)]
 pub struct Standard {}
 
-#[derive(Clone, Copy)]
+#[derive(Debug, Clone, Copy)]
 pub struct Fixed {}
 
 pub trait Mode {
@@ -46,13 +53,20 @@ impl Mode for Fixed {
     type ClientType = FixedMaskClient;
 }
 
-#[derive(Clone)]
+#[derive(Debug, Clone)]
 pub struct WsConnect<T, M = Simple> {
     conn: T,
     conf: WsConf,
     _marker: PhantomData<M>,
 }
 
+impl<T, M> Display for WsConnect<T, M>
+where
+    T: Display,
+{
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result { write!(f, "[ws]{}", self.conn) }
+}
+
 impl<T> WsConnect<T> {
     #[inline]
     pub const fn new(conn: T, conf: WsConf) -> Self {
@@ -115,6 +129,13 @@ pub struct WsAccept<T> {
     conf: WsConf,
 }
 
+impl<T> Display for WsAccept<T>
+where
+    T: Display,
+{
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result { write!(f, "[ws]{}", self.lis) }
+}
+
 impl<T> WsAccept<T> {
     #[inline]
     pub const fn new(lis: T, conf: WsConf) -> Self { Self { lis, conf } }
